@@ -5,17 +5,19 @@ JC cli module
 import io
 import sys
 import os
+import re
+from itertools import islice
 from datetime import datetime, timezone
 import textwrap
 import shlex
 import subprocess
-from typing import List, Union, Optional, TextIO
+from typing import List, Dict, Iterable, Union, Optional, TextIO
 from types import ModuleType
 from .lib import (
     __version__, parser_info, all_parser_info, parsers, _get_parser, _parser_is_streaming,
     parser_mod_list, standard_parser_mod_list, plugin_parser_mod_list, streaming_parser_mod_list
 )
-from .jc_types import JSONDictType, AboutJCType, MetadataType, CustomColorType, ParserInfoType
+from .jc_types import JSONDictType, CustomColorType, ParserInfoType
 from . import utils
 from .cli_data import (
     long_options_map, new_pygments_colors, old_pygments_colors, helptext_preamble_string,
@@ -40,6 +42,10 @@ except Exception:
 JC_CLEAN_EXIT: int = 0
 JC_ERROR_EXIT: int = 100
 MAX_EXIT: int = 255
+SLICER_PATTERN: str = r'-?[0-9]*\:-?[0-9]*$'
+SLICER_RE = re.compile(SLICER_PATTERN)
+NEWLINES_PATTERN: str = r'(\r\n|\r|\n)'
+NEWLINES_RE = re.compile(NEWLINES_PATTERN)
 
 
 class info():
@@ -48,7 +54,7 @@ class info():
     author: str = 'Kelly Brazil'
     author_email: str = 'kellyjonbrazil@gmail.com'
     website: str = 'https://github.com/kellyjonbrazil/jc'
-    copyright: str = '© 2019-2022 Kelly Brazil'
+    copyright: str = '© 2019-2023 Kelly Brazil'
     license: str = 'MIT License'
 
 
@@ -64,17 +70,17 @@ if PYGMENTS_INSTALLED:
 class JcCli():
     __slots__ = (
         'data_in', 'data_out', 'options', 'args', 'parser_module', 'parser_name', 'indent', 'pad',
-        'custom_colors', 'show_hidden', 'ascii_only', 'json_separators', 'json_indent',
-        'run_timestamp', 'about', 'debug', 'verbose_debug', 'force_color', 'mono', 'help_me',
-        'pretty', 'quiet', 'ignore_exceptions', 'raw', 'meta_out', 'unbuffer', 'version_info',
-        'yaml_output', 'bash_comp', 'zsh_comp', 'magic_found_parser', 'magic_options',
-        'magic_run_command', 'magic_run_command_str', 'magic_stdout', 'magic_stderr',
-        'magic_returncode'
+        'custom_colors', 'show_hidden', 'show_categories', 'ascii_only', 'json_separators',
+        'json_indent', 'run_timestamp', 'about', 'debug', 'verbose_debug', 'force_color', 'mono',
+        'help_me', 'pretty', 'quiet', 'ignore_exceptions', 'raw', 'meta_out', 'unbuffer',
+        'version_info', 'yaml_output', 'bash_comp', 'zsh_comp', 'magic_found_parser',
+        'magic_options', 'magic_run_command', 'magic_run_command_str', 'magic_stdout',
+        'magic_stderr', 'magic_returncode', 'slice_str', 'slice_start', 'slice_end'
     )
 
     def __init__(self) -> None:
-        self.data_in: Optional[Union[str, bytes, TextIO]] = None
-        self.data_out: Optional[Union[List[JSONDictType], JSONDictType, AboutJCType]] = None
+        self.data_in: Optional[Union[str, bytes, TextIO, Iterable[str]]] = None
+        self.data_out: Optional[Union[List[JSONDictType], JSONDictType]] = None
         self.options: List[str] = []
         self.args: List[str] = []
         self.parser_module: Optional[ModuleType] = None
@@ -83,11 +89,17 @@ class JcCli():
         self.pad: int = 0
         self.custom_colors: CustomColorType = {}
         self.show_hidden: bool = False
+        self.show_categories: bool = False
         self.ascii_only: bool = False
         self.json_separators: Optional[tuple[str, str]] = (',', ':')
         self.json_indent: Optional[int] = None
         self.run_timestamp: Optional[datetime] = None
 
+        # slicer
+        self.slice_str: str = ''
+        self.slice_start: Optional[int] = None
+        self.slice_end: Optional[int] = None
+
         # cli options
         self.about: bool = False
         self.debug: bool = False
@@ -198,6 +210,41 @@ class JcCli():
 
         return ptext
 
+    def parser_categories_text(self) -> str:
+        """Return lists of parsers by category"""
+        category_text: str = ''
+        padding_char: str = ' '
+        all_parsers = all_parser_info(show_hidden=True, show_deprecated=False)
+        generic = [{'arg': x['argument'], 'desc': x['description']} for x in all_parsers if 'generic' in x.get('tags', [])]
+        standard = [{'arg': x['argument'], 'desc': x['description']} for x in all_parsers if 'standard' in x.get('tags', [])]
+        command = [{'arg': x['argument'], 'desc': x['description']} for x in all_parsers if 'command' in x.get('tags', [])]
+        file_str_bin = [
+            {'arg': x['argument'], 'desc': x['description']} for x in all_parsers
+                if 'file' in x.get('tags', []) or
+                'string' in x.get('tags', []) or
+                'binary' in x.get('tags', [])
+        ]
+        streaming = [{'arg': x['argument'], 'desc': x['description']} for x in all_parsers if x.get('streaming')]
+        categories: Dict = {
+            'Generic Parsers:': generic,
+            'Standard Spec Parsers:': standard,
+            'File/String/Binary Parsers:': file_str_bin,
+            'Streaming Parsers:': streaming,
+            'Command Parsers:': command
+        }
+
+        for cat, cat_objs in categories.items():
+            category_text += f'{cat}  ({len(cat_objs)})\n'
+            for p in cat_objs:
+                parser_arg: str = p.get('arg', 'UNKNOWN')
+                parser_desc: str = p.get('desc', 'No description available.')
+                padding: int = self.pad - len(parser_arg)
+                padding_text: str = padding_char * padding
+                category_text += f'{parser_arg}{padding_text}{parser_desc}\n'
+            category_text += '\n'
+
+        return category_text[:-1]
+
     def options_text(self) -> str:
         """Return the argument and description information from each option"""
         otext: str = ''
@@ -214,7 +261,7 @@ class JcCli():
         return otext
 
     @staticmethod
-    def about_jc() -> AboutJCType:
+    def about_jc() -> JSONDictType:
         """Return jc info and the contents of each parser.info as a dictionary"""
         return {
             'name': 'jc',
@@ -236,8 +283,6 @@ class JcCli():
 
     def helptext(self) -> str:
         """Return the help text with the list of parsers"""
-        self.indent = 4
-        self.pad = 20
         parsers_string: str = self.parsers_text()
         options_string: str = self.options_text()
         helptext_string: str = f'{helptext_preamble_string}{parsers_string}\nOptions:\n{options_string}\n{helptext_end_string}'
@@ -248,6 +293,13 @@ class JcCli():
         Pages the parser documentation if a parser is found in the arguments,
         otherwise the general help text is printed.
         """
+        self.indent = 4
+        self.pad = 22
+
+        if self.show_categories:
+            utils._safe_print(self.parser_categories_text())
+            return
+
         for arg in self.args:
             parser_name: str = self.parser_shortname(arg)
 
@@ -391,6 +443,17 @@ class JcCli():
                 self.magic_options = []
                 return
 
+            # slicer found
+            if ':' in arg:
+                if SLICER_RE.match(arg):
+                    self.slice_str = arg
+                    args_given.pop(0)
+                    continue
+                else:
+                    utils.warning_message(['Invalid slice syntax.'])
+                    args_given.pop(0)
+                    continue
+
             # option found - populate option list
             if arg.startswith('-'):
                 self.magic_options.extend(args_given.pop(0)[1:])
@@ -533,9 +596,108 @@ class JcCli():
             utils.error_message(['Missing piped data. Use "jc -h" for help.'])
             self.exit_error()
 
+    def add_metadata_to_output(self) -> None:
+        """
+        This function mutates data_out in place. If the _jc_meta field
+        does not already exist, it will be created with the metadata fields. If
+        the _jc_meta field already exists, the metadata fields will be added to
+        the existing object.
+
+        In the case of an empty list (no data), a dictionary with a _jc_meta
+        object will be added to the list. This way you always get metadata,
+        even if there are no results.
+        """
+        if self.run_timestamp:
+            meta_obj: JSONDictType = {
+                'parser': self.parser_name,
+                'timestamp': self.run_timestamp.timestamp(),
+                'slice_start': self.slice_start,
+                'slice_end': self.slice_end
+            }
+
+            if self.magic_run_command:
+                meta_obj['magic_command'] = self.magic_run_command
+                meta_obj['magic_command_exit'] = self.magic_returncode
+
+            if isinstance(self.data_out, dict):
+                if '_jc_meta' not in self.data_out:
+                    self.data_out['_jc_meta'] = {}
+
+                self.data_out['_jc_meta'].update(meta_obj)
+
+            elif isinstance(self.data_out, list):
+                if not self.data_out:
+                    self.data_out.append({})
+
+                for item in self.data_out:
+                    if isinstance(item, dict):
+                        if '_jc_meta' not in item:
+                            item['_jc_meta'] = {}
+
+                        item['_jc_meta'].update(meta_obj)
+
+            else:
+                utils.error_message(['Parser returned an unsupported object type.'])
+                self.exit_error()
+
+    @staticmethod
+    def lazy_splitlines(text: str) -> Iterable[str]:
+        start = 0
+        for m in NEWLINES_RE.finditer(text):
+            begin, end = m.span()
+            if begin != start:
+                yield text[start:begin]
+            start = end
+
+        if text[start:]:
+            yield text[start:]
+
+    def slicer(self) -> None:
+        """Slice input data lazily, if possible. Updates self.data_in"""
+        if self.slice_str:
+            slice_start_str, slice_end_str = self.slice_str.split(':', maxsplit=1)
+            if slice_start_str:
+                self.slice_start = int(slice_start_str)
+            if slice_end_str:
+                self.slice_end = int(slice_end_str)
+
+        if not self.slice_start is None or not self.slice_end is None:
+            # standard parsers UTF-8 input
+            if isinstance(self.data_in, str):
+                data_in_iter = self.lazy_splitlines(self.data_in)
+
+                # positive slices
+                if (self.slice_start is None or self.slice_start >= 0) \
+                    and (self.slice_end is None or self.slice_end >= 0):
+
+                    self.data_in = '\n'.join(islice(data_in_iter, self.slice_start, self.slice_end))
+
+                # negative slices found (non-lazy, uses more memory)
+                else:
+                    self.data_in = '\n'.join(list(data_in_iter)[self.slice_start:self.slice_end])
+
+            # standard parsers bytes input
+            elif isinstance(self.data_in, bytes):
+                utils.warning_message(['Cannot slice bytes data.'])
+
+            # streaming parsers UTF-8 input
+            else:
+                # positive slices
+                if (self.slice_start is None or self.slice_start >= 0) \
+                    and (self.slice_end is None or self.slice_end >= 0) \
+                    and self.data_in:
+
+                    self.data_in = islice(self.data_in, self.slice_start, self.slice_end)
+
+                # negative slices found (non-lazy, uses more memory)
+                elif self.data_in:
+                    self.data_in = list(self.data_in)[self.slice_start:self.slice_end]
+
     def streaming_parse_and_print(self) -> None:
         """only supports UTF-8 string data for now"""
         self.data_in = sys.stdin
+        self.slicer()
+
         if self.parser_module:
             result = self.parser_module.parse(
                 self.data_in,
@@ -563,6 +725,8 @@ class JcCli():
         except UnicodeDecodeError:
             pass
 
+        self.slicer()
+
         if self.parser_module:
             self.data_out = self.parser_module.parse(
                 self.data_in,
@@ -586,48 +750,6 @@ class JcCli():
         exit_code = min(exit_code, MAX_EXIT)
         sys.exit(exit_code)
 
-    def add_metadata_to_output(self) -> None:
-        """
-        This function mutates data_out in place. If the _jc_meta field
-        does not already exist, it will be created with the metadata fields. If
-        the _jc_meta field already exists, the metadata fields will be added to
-        the existing object.
-
-        In the case of an empty list (no data), a dictionary with a _jc_meta
-        object will be added to the list. This way you always get metadata,
-        even if there are no results.
-        """
-        if self.run_timestamp:
-            meta_obj: MetadataType = {
-                'parser': self.parser_name,
-                'timestamp': self.run_timestamp.timestamp()
-            }
-
-            if self.magic_run_command:
-                meta_obj['magic_command'] = self.magic_run_command
-                meta_obj['magic_command_exit'] = self.magic_returncode
-
-            if isinstance(self.data_out, dict):
-                if '_jc_meta' not in self.data_out:
-                    self.data_out['_jc_meta'] = {}  # type: ignore
-
-                self.data_out['_jc_meta'].update(meta_obj)  # type: ignore
-
-            elif isinstance(self.data_out, list):
-                if not self.data_out:
-                    self.data_out.append({})
-
-                for item in self.data_out:
-                    if isinstance(item, dict):
-                        if '_jc_meta' not in item:
-                            item['_jc_meta'] = {}
-
-                        item['_jc_meta'].update(meta_obj)  # type: ignore
-
-            else:
-                utils.error_message(['Parser returned an unsupported object type.'])
-                self.exit_error()
-
     def _run(self) -> None:
         # enable colors for Windows cmd.exe terminal
         if sys.platform.startswith('win32'):
@@ -643,6 +765,9 @@ class JcCli():
         # find options if magic_parser did not find a command
         if not self.magic_found_parser:
             for opt in self.args:
+                if SLICER_RE.match(opt):
+                    self.slice_str = opt
+
                 if opt in long_options_map:
                     self.options.extend(long_options_map[opt][0])
 
@@ -655,6 +780,7 @@ class JcCli():
         self.force_color = 'C' in self.options
         self.help_me = 'h' in self.options
         self.show_hidden = self.options.count('h') > 1   # verbose help
+        self.show_categories = self.options.count('h') > 2
         self.pretty = 'p' in self.options
         self.quiet = 'q' in self.options
         self.ignore_exceptions = self.options.count('q') > 1
