@@ -9,7 +9,7 @@ from .jc_types import ParserInfoType, JSONDictType
 from jc import appdirs
 
 
-__version__ = '1.23.2'
+__version__ = '1.23.4'
 
 parsers: List[str] = [
     'acpi',
@@ -43,6 +43,7 @@ parsers: List[str] = [
     'email-address',
     'env',
     'file',
+    'find',
     'findmnt',
     'finger',
     'free',
@@ -66,6 +67,7 @@ parsers: List[str] = [
     'iostat-s',
     'ip-address',
     'iptables',
+    'ip-route',
     'iso-datetime',
     'iw-scan',
     'iwconfig',
@@ -76,6 +78,7 @@ parsers: List[str] = [
     'last',
     'ls',
     'ls-s',
+    'lsattr',
     'lsblk',
     'lsmod',
     'lsof',
@@ -142,6 +145,7 @@ parsers: List[str] = [
     'proc-net-packet',
     'proc-net-protocols',
     'proc-net-route',
+    'proc-net-tcp',
     'proc-net-unix',
     'proc-pid-fdinfo',
     'proc-pid-io',
@@ -153,6 +157,7 @@ parsers: List[str] = [
     'proc-pid-statm',
     'proc-pid-status',
     'ps',
+    'resolve-conf',
     'route',
     'rpm-qi',
     'rsync',
@@ -160,6 +165,7 @@ parsers: List[str] = [
     'semver',
     'sfdisk',
     'shadow',
+    'srt',
     'ss',
     'ssh-conf',
     'sshd-conf',
@@ -193,12 +199,14 @@ parsers: List[str] = [
     'uptime',
     'url',
     'ver',
+    'veracrypt',
     'vmstat',
     'vmstat-s',
     'w',
     'wc',
     'who',
     'x509-cert',
+    'x509-csr',
     'xml',
     'xrandr',
     'yaml',
